@@ -27,13 +27,13 @@ test_that("generate_uid returns a function", {
 })
 
 test_that("show_fields returns no fields", {
-  dt <- load_datatype("https://doi.org/21.T11969/1ea0e148d9bbe08335cd")
-  no_fields <- show_fields(dt$pidinst_schemaobject())
+  dt <- load_datatype("https://doi.org/21.T11969/3df63b7acb0522da685d")
+  no_fields <- show_fields(dt$string())
   expect_equal(no_fields, NULL)
 })
 
 test_that("show_fields returns expected fields", {
-  dt <- load_datatype("https://doi.org/21.T11969/74bc7748b8cd520908bc")
+  dt <- load_datatype("https://doi.org/21.T11969/0424f6e7026fa4bc2c4a")
   shown_fields <- show_fields(dt$table())
   expect_equal(shown_fields, c("rows", "columns", "label"))
 })
